# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel

__all__ = [
    "Session",
    "RecallOptions",
    "RecallOptionsVectorDocSearch",
    "RecallOptionsTextOnlyDocSearch",
    "RecallOptionsHybridDocSearch",
]


class RecallOptionsVectorDocSearch(BaseModel):
    confidence: Optional[float] = None

    lang: Optional[str] = None

    limit: Optional[int] = None

    max_query_length: Optional[int] = None

    metadata_filter: Optional[object] = None

    mmr_strength: Optional[float] = None

    mode: Optional[str] = None

    num_search_messages: Optional[int] = None


class RecallOptionsTextOnlyDocSearch(BaseModel):
    lang: Optional[str] = None

    limit: Optional[int] = None

    max_query_length: Optional[int] = None

    metadata_filter: Optional[object] = None

    mode: Optional[str] = None

    num_search_messages: Optional[int] = None


class RecallOptionsHybridDocSearch(BaseModel):
    alpha: Optional[float] = None

    confidence: Optional[float] = None

    lang: Optional[str] = None

    limit: Optional[int] = None

    max_query_length: Optional[int] = None

    metadata_filter: Optional[object] = None

    mmr_strength: Optional[float] = None

    mode: Optional[str] = None

    num_search_messages: Optional[int] = None


RecallOptions: TypeAlias = Union[
    RecallOptionsVectorDocSearch, RecallOptionsTextOnlyDocSearch, RecallOptionsHybridDocSearch, None
]


class Session(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    auto_run_tools: Optional[bool] = None

    context_overflow: Optional[Literal["truncate", "adaptive"]] = None

    forward_tool_calls: Optional[bool] = None

    kind: Optional[str] = None

    metadata: Optional[object] = None

    recall_options: Optional[RecallOptions] = None

    render_templates: Optional[bool] = None

    situation: Optional[str] = None

    summary: Optional[str] = None

    system_template: Optional[str] = None

    token_budget: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime

from .._models import BaseModel

__all__ = ["Agent"]


class Agent(BaseModel):
    id: str

    created_at: datetime

    name: str

    updated_at: datetime

    about: Optional[str] = None

    canonical_name: Optional[str] = None

    default_settings: Optional[object] = None

    default_system_template: Optional[str] = None

    instructions: Union[str, List[str], None] = None

    metadata: Optional[object] = None

    model: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable, Optional
from typing_extensions import Literal, Required, TypeAlias, TypedDict

__all__ = [
    "MessageParam",
    "ContentUnionMember2",
    "ContentUnionMember2Content",
    "ContentUnionMember2ContentModel7",
    "ContentUnionMember2ContentModel7ImageURL",
    "ContentUnionMember2AgentsAPIAutogenChatContentModel",
    "ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember0",
    "ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1",
    "ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1Source",
    "ToolCall",
    "ToolCallChosenFunctionCall",
    "ToolCallChosenFunctionCallFunction",
    "ToolCallChosenFunctionCallBash20241022",
    "ToolCallChosenFunctionCallComputer20241022",
    "ToolCallChosenFunctionCallTextEditor20241022",
    "ToolCallChosenComputer20241022",
    "ToolCallChosenTextEditor20241022",
    "ToolCallChosenBash20241022",
]


class ContentUnionMember2Content(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class ContentUnionMember2ContentModel7ImageURL(TypedDict, total=False):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class ContentUnionMember2ContentModel7(TypedDict, total=False):
    image_url: Required[ContentUnionMember2ContentModel7ImageURL]
    """The image URL"""

    type: Literal["image_url"]


class ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember0(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1Source(TypedDict, total=False):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1(TypedDict, total=False):
    source: Required[ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1Source]

    type: Literal["image"]


class ContentUnionMember2AgentsAPIAutogenChatContentModel(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember0],
            Iterable[ContentUnionMember2AgentsAPIAutogenChatContentModelContentUnionMember1],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


ContentUnionMember2: TypeAlias = Union[
    ContentUnionMember2Content, ContentUnionMember2ContentModel7, ContentUnionMember2AgentsAPIAutogenChatContentModel
]


class ToolCallChosenFunctionCallFunction(TypedDict, total=False):
    name: Required[str]

    arguments: Optional[str]


class ToolCallChosenFunctionCallBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


class ToolCallChosenFunctionCallComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class ToolCallChosenFunctionCallTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class ToolCallChosenFunctionCall(TypedDict, total=False):
    function: Required[ToolCallChosenFunctionCallFunction]

    api_call: object

    bash_20241022: Optional[ToolCallChosenFunctionCallBash20241022]

    computer_20241022: Optional[ToolCallChosenFunctionCallComputer20241022]

    integration: object

    system: object

    text_editor_20241022: Optional[ToolCallChosenFunctionCallTextEditor20241022]

    type: Literal["function"]


class ToolCallChosenComputer20241022(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "cursor_position",
            "mouse_move",
            "left_click",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
        ]
    ]

    coordinate: Optional[Iterable[int]]

    text: Optional[str]


class ToolCallChosenTextEditor20241022(TypedDict, total=False):
    command: Required[Literal["str_replace", "insert", "view", "undo_edit"]]

    path: Required[str]

    file_text: Optional[str]

    insert_line: Optional[int]

    new_str: Optional[str]

    old_str: Optional[str]

    view_range: Optional[Iterable[int]]


class ToolCallChosenBash20241022(TypedDict, total=False):
    command: Optional[str]

    restart: bool


ToolCall: TypeAlias = Union[
    ToolCallChosenFunctionCall,
    ToolCallChosenComputer20241022,
    ToolCallChosenTextEditor20241022,
    ToolCallChosenBash20241022,
]

_MessageParamReservedKeywords = TypedDict(
    "_MessageParamReservedKeywords",
    {
        "continue": Optional[bool],
    },
    total=False,
)


class MessageParam(_MessageParamReservedKeywords, total=False):
    role: Required[Literal["user", "assistant", "system", "tool"]]

    content: Union[str, List[str], Iterable[ContentUnionMember2], None]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[ToolCall]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from .snippet import Snippet
from .._models import BaseModel

__all__ = [
    "ChatResponse",
    "Choice",
    "ChoiceSingleChatOutput",
    "ChoiceSingleChatOutputMessage",
    "ChoiceSingleChatOutputMessageContentUnionMember2",
    "ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source",
    "ChoiceSingleChatOutputMessageToolCall",
    "ChoiceSingleChatOutputMessageToolCallChosenFunctionCall",
    "ChoiceSingleChatOutputMessageToolCallChosenFunctionCallFunction",
    "ChoiceSingleChatOutputMessageToolCallChosenFunctionCallBash20241022",
    "ChoiceSingleChatOutputMessageToolCallChosenFunctionCallComputer20241022",
    "ChoiceSingleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022",
    "ChoiceSingleChatOutputMessageToolCallChosenComputer20241022",
    "ChoiceSingleChatOutputMessageToolCallChosenTextEditor20241022",
    "ChoiceSingleChatOutputMessageToolCallChosenBash20241022",
    "ChoiceSingleChatOutputLogprobs",
    "ChoiceSingleChatOutputLogprobsContent",
    "ChoiceSingleChatOutputLogprobsContentTopLogprob",
    "ChoiceSingleChatOutputToolCall",
    "ChoiceSingleChatOutputToolCallChosenFunctionCall",
    "ChoiceSingleChatOutputToolCallChosenFunctionCallFunction",
    "ChoiceSingleChatOutputToolCallChosenFunctionCallBash20241022",
    "ChoiceSingleChatOutputToolCallChosenFunctionCallComputer20241022",
    "ChoiceSingleChatOutputToolCallChosenFunctionCallTextEditor20241022",
    "ChoiceSingleChatOutputToolCallChosenComputer20241022",
    "ChoiceSingleChatOutputToolCallChosenTextEditor20241022",
    "ChoiceSingleChatOutputToolCallChosenBash20241022",
    "ChoiceMultipleChatOutput",
    "ChoiceMultipleChatOutputMessage",
    "ChoiceMultipleChatOutputMessageContentUnionMember2",
    "ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source",
    "ChoiceMultipleChatOutputMessageToolCall",
    "ChoiceMultipleChatOutputMessageToolCallChosenFunctionCall",
    "ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallFunction",
    "ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallBash20241022",
    "ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallComputer20241022",
    "ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022",
    "ChoiceMultipleChatOutputMessageToolCallChosenComputer20241022",
    "ChoiceMultipleChatOutputMessageToolCallChosenTextEditor20241022",
    "ChoiceMultipleChatOutputMessageToolCallChosenBash20241022",
    "ChoiceMultipleChatOutputLogprobs",
    "ChoiceMultipleChatOutputLogprobsContent",
    "ChoiceMultipleChatOutputLogprobsContentTopLogprob",
    "ChoiceMultipleChatOutputToolCall",
    "ChoiceMultipleChatOutputToolCallChosenFunctionCall",
    "ChoiceMultipleChatOutputToolCallChosenFunctionCallFunction",
    "ChoiceMultipleChatOutputToolCallChosenFunctionCallBash20241022",
    "ChoiceMultipleChatOutputToolCallChosenFunctionCallComputer20241022",
    "ChoiceMultipleChatOutputToolCallChosenFunctionCallTextEditor20241022",
    "ChoiceMultipleChatOutputToolCallChosenComputer20241022",
    "ChoiceMultipleChatOutputToolCallChosenTextEditor20241022",
    "ChoiceMultipleChatOutputToolCallChosenBash20241022",
    "Doc",
    "DocOwner",
    "Usage",
]


class ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7(BaseModel):
    image_url: ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1(BaseModel):
    source: ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4(BaseModel):
    content: Union[
        List[ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0],
        List[ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


ChoiceSingleChatOutputMessageContentUnionMember2: TypeAlias = Union[
    ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3,
    ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7,
    ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4,
]


class ChoiceSingleChatOutputMessageToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class ChoiceSingleChatOutputMessageToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class ChoiceSingleChatOutputMessageToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceSingleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceSingleChatOutputMessageToolCallChosenFunctionCall(BaseModel):
    function: ChoiceSingleChatOutputMessageToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[ChoiceSingleChatOutputMessageToolCallChosenFunctionCallBash20241022] = None

    computer_20241022: Optional[ChoiceSingleChatOutputMessageToolCallChosenFunctionCallComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[ChoiceSingleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022] = None

    type: Optional[Literal["function"]] = None


class ChoiceSingleChatOutputMessageToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceSingleChatOutputMessageToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceSingleChatOutputMessageToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


ChoiceSingleChatOutputMessageToolCall: TypeAlias = Union[
    ChoiceSingleChatOutputMessageToolCallChosenFunctionCall,
    ChoiceSingleChatOutputMessageToolCallChosenComputer20241022,
    ChoiceSingleChatOutputMessageToolCallChosenTextEditor20241022,
    ChoiceSingleChatOutputMessageToolCallChosenBash20241022,
]


class ChoiceSingleChatOutputMessage(BaseModel):
    role: Literal["user", "assistant", "system", "tool"]

    id: Optional[str] = None

    content: Union[str, List[str], List[ChoiceSingleChatOutputMessageContentUnionMember2], None] = None

    created_at: Optional[datetime] = None

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[ChoiceSingleChatOutputMessageToolCall]] = None


class ChoiceSingleChatOutputLogprobsContentTopLogprob(BaseModel):
    token: str

    logprob: float

    bytes: Optional[List[int]] = None


class ChoiceSingleChatOutputLogprobsContent(BaseModel):
    token: str

    logprob: float

    top_logprobs: List[ChoiceSingleChatOutputLogprobsContentTopLogprob]

    bytes: Optional[List[int]] = None


class ChoiceSingleChatOutputLogprobs(BaseModel):
    content: Optional[List[ChoiceSingleChatOutputLogprobsContent]] = None


class ChoiceSingleChatOutputToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class ChoiceSingleChatOutputToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class ChoiceSingleChatOutputToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceSingleChatOutputToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceSingleChatOutputToolCallChosenFunctionCall(BaseModel):
    function: ChoiceSingleChatOutputToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[ChoiceSingleChatOutputToolCallChosenFunctionCallBash20241022] = None

    computer_20241022: Optional[ChoiceSingleChatOutputToolCallChosenFunctionCallComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[ChoiceSingleChatOutputToolCallChosenFunctionCallTextEditor20241022] = None

    type: Optional[Literal["function"]] = None


class ChoiceSingleChatOutputToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceSingleChatOutputToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceSingleChatOutputToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


ChoiceSingleChatOutputToolCall: TypeAlias = Union[
    ChoiceSingleChatOutputToolCallChosenFunctionCall,
    ChoiceSingleChatOutputToolCallChosenComputer20241022,
    ChoiceSingleChatOutputToolCallChosenTextEditor20241022,
    ChoiceSingleChatOutputToolCallChosenBash20241022,
]


class ChoiceSingleChatOutput(BaseModel):
    index: int

    message: ChoiceSingleChatOutputMessage

    finish_reason: Optional[Literal["stop", "length", "content_filter", "tool_calls"]] = None

    logprobs: Optional[ChoiceSingleChatOutputLogprobs] = None

    tool_calls: Optional[List[ChoiceSingleChatOutputToolCall]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7(BaseModel):
    image_url: ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1(BaseModel):
    source: ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4(BaseModel):
    content: Union[
        List[ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0],
        List[ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


ChoiceMultipleChatOutputMessageContentUnionMember2: TypeAlias = Union[
    ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3,
    ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7,
    ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4,
]


class ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceMultipleChatOutputMessageToolCallChosenFunctionCall(BaseModel):
    function: ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallBash20241022] = None

    computer_20241022: Optional[ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[ChoiceMultipleChatOutputMessageToolCallChosenFunctionCallTextEditor20241022] = None

    type: Optional[Literal["function"]] = None


class ChoiceMultipleChatOutputMessageToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceMultipleChatOutputMessageToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceMultipleChatOutputMessageToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


ChoiceMultipleChatOutputMessageToolCall: TypeAlias = Union[
    ChoiceMultipleChatOutputMessageToolCallChosenFunctionCall,
    ChoiceMultipleChatOutputMessageToolCallChosenComputer20241022,
    ChoiceMultipleChatOutputMessageToolCallChosenTextEditor20241022,
    ChoiceMultipleChatOutputMessageToolCallChosenBash20241022,
]


class ChoiceMultipleChatOutputMessage(BaseModel):
    role: Literal["user", "assistant", "system", "tool"]

    id: Optional[str] = None

    content: Union[str, List[str], List[ChoiceMultipleChatOutputMessageContentUnionMember2], None] = None

    created_at: Optional[datetime] = None

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[ChoiceMultipleChatOutputMessageToolCall]] = None


class ChoiceMultipleChatOutputLogprobsContentTopLogprob(BaseModel):
    token: str

    logprob: float

    bytes: Optional[List[int]] = None


class ChoiceMultipleChatOutputLogprobsContent(BaseModel):
    token: str

    logprob: float

    top_logprobs: List[ChoiceMultipleChatOutputLogprobsContentTopLogprob]

    bytes: Optional[List[int]] = None


class ChoiceMultipleChatOutputLogprobs(BaseModel):
    content: Optional[List[ChoiceMultipleChatOutputLogprobsContent]] = None


class ChoiceMultipleChatOutputToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class ChoiceMultipleChatOutputToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class ChoiceMultipleChatOutputToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceMultipleChatOutputToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceMultipleChatOutputToolCallChosenFunctionCall(BaseModel):
    function: ChoiceMultipleChatOutputToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[ChoiceMultipleChatOutputToolCallChosenFunctionCallBash20241022] = None

    computer_20241022: Optional[ChoiceMultipleChatOutputToolCallChosenFunctionCallComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[ChoiceMultipleChatOutputToolCallChosenFunctionCallTextEditor20241022] = None

    type: Optional[Literal["function"]] = None


class ChoiceMultipleChatOutputToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class ChoiceMultipleChatOutputToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class ChoiceMultipleChatOutputToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


ChoiceMultipleChatOutputToolCall: TypeAlias = Union[
    ChoiceMultipleChatOutputToolCallChosenFunctionCall,
    ChoiceMultipleChatOutputToolCallChosenComputer20241022,
    ChoiceMultipleChatOutputToolCallChosenTextEditor20241022,
    ChoiceMultipleChatOutputToolCallChosenBash20241022,
]


class ChoiceMultipleChatOutput(BaseModel):
    index: int

    messages: List[ChoiceMultipleChatOutputMessage]

    finish_reason: Optional[Literal["stop", "length", "content_filter", "tool_calls"]] = None

    logprobs: Optional[ChoiceMultipleChatOutputLogprobs] = None

    tool_calls: Optional[List[ChoiceMultipleChatOutputToolCall]] = None


Choice: TypeAlias = Union[ChoiceSingleChatOutput, ChoiceMultipleChatOutput]


class DocOwner(BaseModel):
    id: str

    role: Literal["user", "agent"]


class Doc(BaseModel):
    id: str

    owner: DocOwner

    snippet: Snippet

    distance: Optional[float] = None

    metadata: Optional[object] = None

    title: Optional[str] = None


class Usage(BaseModel):
    completion_tokens: Optional[int] = None

    prompt_tokens: Optional[int] = None

    total_tokens: Optional[int] = None


class ChatResponse(BaseModel):
    id: str

    choices: List[Choice]

    created_at: datetime

    docs: Optional[List[Doc]] = None

    jobs: Optional[List[str]] = None

    usage: Optional[Usage] = None
    """Usage statistics for the completion request"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal, TypeAlias, TypedDict

__all__ = [
    "SessionResetParams",
    "RecallOptions",
    "RecallOptionsVectorDocSearch",
    "RecallOptionsTextOnlyDocSearch",
    "RecallOptionsHybridDocSearch",
]


class SessionResetParams(TypedDict, total=False):
    auto_run_tools: bool

    context_overflow: Optional[Literal["truncate", "adaptive"]]

    forward_tool_calls: bool

    metadata: Optional[object]

    recall_options: Optional[RecallOptions]

    render_templates: bool

    situation: Optional[str]

    system_template: Optional[str]

    token_budget: Optional[int]


class RecallOptionsVectorDocSearch(TypedDict, total=False):
    confidence: float

    lang: str

    limit: int

    max_query_length: int

    metadata_filter: object

    mmr_strength: float

    mode: str

    num_search_messages: int


class RecallOptionsTextOnlyDocSearch(TypedDict, total=False):
    lang: str

    limit: int

    max_query_length: int

    metadata_filter: object

    mode: str

    num_search_messages: int


class RecallOptionsHybridDocSearch(TypedDict, total=False):
    alpha: float

    confidence: float

    lang: str

    limit: int

    max_query_length: int

    metadata_filter: object

    mmr_strength: float

    mode: str

    num_search_messages: int


RecallOptions: TypeAlias = Union[
    RecallOptionsVectorDocSearch, RecallOptionsTextOnlyDocSearch, RecallOptionsHybridDocSearch
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

__all__ = ["TransitionListParams"]


class TransitionListParams(TypedDict, total=False):
    direction: Literal["asc", "desc"]

    limit: int

    offset: int

    scope_id: Optional[str]

    sort_by: Literal["created_at", "updated_at"]
